@@ -1,6 +1,5 @@
 from typing import Optional, Dict, List, Tuple, Callable, IO
 
-import time
 from io import BytesIO
 
 from baidupcs_py.common import constant
@@ -47,7 +46,7 @@ class BaiduPCSApi:
 
     @property
     def bdstoken(self) -> str:
-        return self._baidupcs._bdstoken
+        return self._baidupcs.bdstoken
 
     @property
     def stoken(self) -> Optional[str]:
@@ -220,6 +219,12 @@ class BaiduPCSApi:
         info = self._baidupcs.add_task(task_url, remotedir)
         return str(info["task_id"])
 
+    def add_magnet_task(
+        self, task_url: str, remotedir: str, selected_idx: List[int]
+    ) -> str:
+        info = self._baidupcs.add_magnet_task(task_url, remotedir, selected_idx)
+        return str(info["task_id"])
+
     def tasks(self, *task_ids: str) -> List[CloudTask]:
         info = self._baidupcs.tasks(*task_ids)
         tasks = []
