@@ -259,8 +259,10 @@ TASK_STATUS_MSG = {
     4: "下载超时",
     5: "资源存在但下载失败",
     6: "存储空间不足",
-    7: "目标地址数据已存在",
-    8: "任务取消",
+    7: "任务取消",
+    8: "目标地址数据已存在",
+    9: "任务删除",
+    10: "部分下载成功",
 }
 
 
