@@ -80,7 +80,7 @@ def from_tos(localpaths: List[str], remotedir: str) -> List[FromTo]:
             remotepath = to_remotepath(os.path.basename(localpath), remotedir)
             ft.append(FromTo(localpath, remotepath))
         else:
-            n = len(str(Path(localpath)))
+            n = len(str(Path(localpath).parent))
             for sub_path in walk(localpath):
                 remotepath = to_remotepath(sub_path[n + 1 :], remotedir)
                 ft.append(FromTo(sub_path, remotepath))
@@ -391,6 +391,7 @@ def upload_file(
                         "`upload`: `upload_slice`: error: %s, fail_count: %s",
                         err,
                         fail_count,
+                        exc_info=err,
                     ),
                     _wait_start(),
                 ),
@@ -406,6 +407,7 @@ def upload_file(
                 "`upload`: `combine_slices`: error: %s, fail_count: %s",
                 err,
                 fail_count,
+                exc_info=err,
             ),
         )(api.combine_slices)(
             slice_md5s,
